@@ -7,12 +7,12 @@ from openpyxl.worksheet.worksheet import Worksheet
 from openpyxl_image_loader import SheetImageLoader
 from openpyxl.drawing.image import Image
 
-from xlsx_lib.domain.shared.text_line import TextLine
+from xlsx_lib.domain.shared.NewImageData import NewImageData
+from xlsx_lib.domain.shared.NewImageFile import NewImageFile
+from xlsx_lib.domain.shared.TextLine import TextLine
 from xlsx_lib.domain.distribution.data_block import DataBlock
-from xlsx_lib.domain.distribution.distribution_image import DistributionImage
 from xlsx_lib.domain.distribution.distribution_cell_value_types import DistributionCellValueType
 from xlsx_lib.domain.distribution.distribution_data import DistributionData
-from xlsx_lib.domain.distribution.new_distribution_image import NewImage
 from xlsx_lib.domain.xlsx_elements.exceptions.continue_exception import ContinueException
 from xlsx_lib.domain.xlsx_elements.exceptions.sheet_end_exception import SheetEndException
 from xlsx_lib.domain.xlsx_elements.sheet import Sheet
@@ -30,7 +30,7 @@ class DistributionSheet(Sheet):
             self,
             worksheet: Worksheet,
     ):
-        self.distribution_images: List[NewImage] = []
+        self.distribution_images: List[NewImageFile] = []
         self.distribution_data: DistributionData = DistributionData()
 
         self.max_col: int = 3
@@ -44,21 +44,21 @@ class DistributionSheet(Sheet):
         )
 
         image_loader = SheetImageLoader(worksheet)
-
-        for image in worksheet._images:
-            file_name: str = f"{uuid.uuid4()}.{image.format}"
+        for image_cell in image_loader._images:
+            image = image_loader.get(image_cell)
+            filename: str = f"{uuid.uuid4()}.{image.format.lower()}"
 
             self.distribution_images.append(
-                NewImage(
-                    file_name=file_name,
-                    file=image.ref,
+                NewImageFile(
+                    filename=filename,
+                    file=image.fp,
                 )
             )
 
             self.distribution_data.blocks.append(
                 DataBlock(
-                    image=DistributionImage(
-                        file_name=file_name,
+                    image=NewImageData(
+                        filename=filename,
                         width=image.width,
                         height=image.height,
                     )
